#[repr(u32)]pub enum DataType {
Show 22 variants
Void = 0,
I8 = 1,
I16 = 2,
I32 = 3,
I64 = 4,
U8 = 5,
U16 = 6,
U32 = 7,
U64 = 8,
SingleFloat = 9,
DoubleFloat = 10,
ExtendedFloat = 11,
SingleFloatWithUnit = 25,
DoubleFloatWithUnit = 12,
ExtendedFloatWithUnit = 13,
TdmsString = 32,
Boolean = 33,
Timestamp = 68,
FixedPoint = 79,
ComplexSingleFloat = 524_300,
ComplexDoubleFloat = 1_048_589,
DAQmxRawData = 4_294_967_295,
}Expand description
The data types that can be encoded into TDMS data.
The values are the codes used in the TDMS file.
Variants
Void = 0
I8 = 1
I16 = 2
I32 = 3
I64 = 4
U8 = 5
U16 = 6
U32 = 7
U64 = 8
SingleFloat = 9
DoubleFloat = 10
ExtendedFloat = 11
SingleFloatWithUnit = 25
DoubleFloatWithUnit = 12
ExtendedFloatWithUnit = 13
TdmsString = 32
Boolean = 33
Timestamp = 68
FixedPoint = 79
ComplexSingleFloat = 524_300
ComplexDoubleFloat = 1_048_589
DAQmxRawData = 4_294_967_295
Implementations